@@ -17,7 +17,7 @@ class LocalBackend(BaseBackend):
     """
     A backend for playing music from a local music archive.
 
-    **Issues:** http://github.com/jodal/mopidy/issues/labels/backend-local
+    **Issues:** http://github.com/mopidy/mopidy/issues/labels/backend-local
 
     **Settings:**
 
